==> ylztest-1.4.0.tgz: package/src/api/CommonApi.js <==
/**
 * 基础信息 API
 */
// import md5 from '../utils/md5.js'

const APP_KEY = 'JJSB09$%D89@!@=='
let headers = {'Accept': 'application/json', 'Content-Type': 'application/json'}
const Timestamp = new Date().getTime()
headers['Timestamp'] = Timestamp
/**
 * 定位
 */
const getAddress = () => {
    return new Promise(resolve => {
        wx.getLocation({
            type: 'wgs84',
            success: res => {
                wx.request({
                    url: `https://api.map.baidu.com/geocoder/v2/?callback=renderReverse&location=${res.latitude},${res.longitude}&output=json&pois=1&ak=9RVMCDmuAMNvhR8GkpeeZH1ibtrktd1W`,
                    method: 'GET',
                    data: {},
                    header: headers,
                    success: res => {
                        let allInfo = res.data.split('renderReverse(')[1]
                        let add = JSON.parse(allInfo.substring(0, allInfo.length - 1))
                        resolve(add.result.addressComponent.city)
                    }
                })
            }
        })
    })
}
const xmLogin = (md5, area, mobile, name, password, token) => {
    headers['jjsb-access-token'] = token
    headers['sign'] = md5.hex_md5(`${Timestamp}${token}${APP_KEY}`)
    return new Promise(resolve => {
        wx.request({
            url: `https://shebaoapi.jjshebao.com/v20/accredit/checkLogin`,
            method: 'POST',
            header: headers,
            data: {
                area: area,
                mobile: mobile,
                xmLogin: {
                    username: name.toLocaleUpperCase(),
                    password: password
                },
                fromName: ''
            },
            success: res => {
                resolve(res.data)
            }
        })
    })
}

const fjLogin = (md5, area, mobile, idCard, password, name, code, token) => {
    headers['jjsb-access-token'] = token
    headers['sign'] = md5.hex_md5(`${Timestamp}${token}${APP_KEY}`)
    return new Promise(resolve => {
        wx.request({
            url: `https://shebaoapi.jjshebao.com/v20/accredit/checkLogin`,
            method: 'POST',
            header: headers,
            data: {
                area: area,
                mobile: mobile,
                fromName: name,
                fjLogin: {
                    realName: name,
                    idCard: idCard.toLocaleUpperCase(),
                    password: md5.hex_md5(password + '{PONY}'),
                    code: code
                }
            },
            success: res => {
                resolve(res.data)
            }
        })
    })
}

module.exports = {
    getAddress: getAddress,
    xmLogin: xmLogin,
    fjLogin: fjLogin
}

==> ylztest-1.4.2.tgz: package/src/api/CommonApi.js <==
/**
 * 基础信息 API
 */
// import md5 from '../utils/md5.js'

const APP_KEY = 'JJSB09$%D89@!@=='
let headers = {'Accept': 'application/json', 'Content-Type': 'application/json'}
const Timestamp = new Date().getTime()
headers['Timestamp'] = Timestamp
/**
 * 定位
 */
const getAddress = () => {
    return new Promise(resolve => {
        wx.getLocation({
            type: 'wgs84',
            success: res => {
                wx.request({
                    url: `https://api.map.baidu.com/geocoder/v2/?callback=renderReverse&location=${res.latitude},${res.longitude}&output=json&pois=1&ak=9RVMCDmuAMNvhR8GkpeeZH1ibtrktd1W`,
                    method: 'GET',
                    data: {},
                    header: headers,
                    success: res => {
                        let allInfo = res.data.split('renderReverse(')[1]
                        let add = JSON.parse(allInfo.substring(0, allInfo.length - 1))
                        resolve(add.result.addressComponent.city)
                    }
                })
            }
        })
    })
}
const xmLogin = (md5, area, mobile, name, password, token, type) => {
    headers['jjsb-access-token'] = token
    headers['sign'] = md5.hex_md5(`${Timestamp}${token}${APP_KEY}`)
    return new Promise(resolve => {
        wx.request({
            url: type === 'test' ? `https://tst-apishebao.jjshebao.com/v20/accredit/checkLogin` : `https://shebaoapi.jjshebao.com/v20/accredit/checkLogin`,
            method: 'POST',
            header: headers,
            data: {
                area: area,
                mobile: mobile,
                xmLogin: {
                    username: name.toLocaleUpperCase(),
                    password: password
                },
                fromName: ''
            },
            success: res => {
                resolve(res.data)
            }
        })
    })
}

const fjLogin = (md5, area, mobile, idCard, password, name, code, token, type) => {
    headers['jjsb-access-token'] = token
    headers['sign'] = md5.hex_md5(`${Timestamp}${token}${APP_KEY}`)
    return new Promise(resolve => {
        wx.request({
            url: type === 'test' ? `https://tst-apishebao.jjshebao.com/v20/accredit/checkLogin` : `https://shebaoapi.jjshebao.com/v20/accredit/checkLogin`,
            method: 'POST',
            header: headers,
            data: {
                area: area,
                mobile: mobile,
                fromName: name,
                fjLogin: {
                    realName: name,
                    idCard: idCard.toLocaleUpperCase(),
                    password: md5.hex_md5(password + '{PONY}'),
                    code: code
                }
            },
            success: res => {
                resolve(res.data)
            }
        })
    })
}

module.exports = {
    getAddress: getAddress,
    xmLogin: xmLogin,
    fjLogin: fjLogin
}
